@@ -9,18 +9,18 @@ import sys
 import pptx.exc as exceptions
 sys.modules['pptx.exceptions'] = exceptions
 
-from pptx.api import(Presentation)
+from pptx.api import Presentation  # flake8: noqa
 
-__version__ = '0.2.5'
+__version__ = '0.2.6'
 
 import logging
 log = logging.getLogger('pptx')
 log.setLevel(logging.DEBUG)
-# log.setLevel(logging.INFO)
 ch = logging.StreamHandler()
 ch.setLevel(logging.DEBUG)
-formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s'
-                              ' - %(message)s')
+formatter = logging.Formatter(
+    '%(asctime)s - %(name)s - %(levelname)s - %(message)s'
+)
 ch.setFormatter(formatter)
 log.addHandler(ch)
 
